@@ -93,7 +93,7 @@ def checkout(  # noqa: C901
             src_path = storage.path
         else:
             assert entry.hash_info
-            odb = storage.odb or storage.cache or storage.remote
+            odb = storage.cache or storage.remote
             assert odb
             src_fs = odb.fs
             src_path = odb.oid_to_path(entry.hash_info.value)
